import{cw as r}from"./outputWidgets.32262ea4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="765aa8b0-d8ac-40e5-860a-ea0d334fa966",e._sentryDebugIdIdentifier="sentry-dbid-765aa8b0-d8ac-40e5-860a-ea0d334fa966")}catch{}})();const o=(e,a)=>{r.error({message:e,description:a})};export{o as p};
//# sourceMappingURL=popupNotifcation.f97e9620.js.map
