import{d as u,eB as b,G as f,b as y,c as g,u as _}from"./outputWidgets.32262ea4.js";import{a as w}from"./asyncComputed.2515c9c2.js";import"./authorManager.bf87d9ac.js";import"./index.2dfe4d35.js";import{M as m}from"./member.9c157757.js";import{C as I}from"./CrudView.3a879739.js";import"./index.cf4c23b9.js";import"./record.b25fae92.js";import"./pubsub.688bf9b2.js";import"./gateway.c70bbf22.js";import"./icons.f6f8ddd9.js";import"./Text.5738d3bb.js";import"./Title.4f1fbb5b.js";import"./FormItem.dc863e60.js";import"./hasIn.4e5c4024.js";import"./Form.0ac7561e.js";import"./Modal.1c897574.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.db135e16.js";import"./router.24325fd4.js";import"./index.1d7a7a89.js";import"./url.bc186fa2.js";import"./index.e1a424df.js";import"./index.62cf3b9c.js";import"./index.0278a234.js";import"./index.df3792d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="fc9933da-0767-40aa-8289-029d0b042840",e._sentryDebugIdIdentifier="sentry-dbid-fc9933da-0767-40aa-8289-029d0b042840")}catch{}})();const S=u({__name:"Members",setup(e){const r=b().params.organizationId,n=[{key:"email",label:"Email"}],s=async t=>{await m.create(r,t.email),d()},{loading:l,result:p,refetch:d}=w(()=>m.list(r)),c=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=p.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:n,onCreate:s},null,8,["loading","table"]))}});export{S as default};
//# sourceMappingURL=Members.35916eb8.js.map
