import{a as e,A as a,B as s}from"./Title.4f1fbb5b.js";import{A as o}from"./Link.adad6177.js";import{a as r,A as i}from"./Text.5738d3bb.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="e8ed3021-99bd-4c7f-9638-52e495b197be",n._sentryDebugIdIdentifier="sentry-dbid-e8ed3021-99bd-4c7f-9638-52e495b197be")}catch{}})();e.Text=r;e.Title=a;e.Paragraph=i;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,a),n.component(e.Paragraph.displayName,i),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.7cb42e92.js.map
