import"./outputWidgets.32262ea4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="40002d16-150b-434e-916f-41b45bf6fe62",e._sentryDebugIdIdentifier="sentry-dbid-40002d16-150b-434e-916f-41b45bf6fe62")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.bc186fa2.js.map
