import"./outputWidgets.32262ea4.js";import"./index.c9aa3d70.js";import{M as n}from"./Modal.1c897574.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="45c51c87-4824-4f91-a356-eb14e8b01e47",t._sentryDebugIdIdentifier="sentry-dbid-45c51c87-4824-4f91-a356-eb14e8b01e47")}catch{}})();function c(t){switch(typeof t){case"object":return Object.entries(t).map(([e,r])=>({title:e,key:e,children:c(r)}));default:return[{title:t,key:t}]}}function i(t,e){return new Promise(r=>{n.confirm({title:t,onOk:()=>r(!0),okText:e==null?void 0:e.okText,onCancel:()=>r(!1),cancelText:e==null?void 0:e.cancelText})})}export{i as a,c as t};
//# sourceMappingURL=ant-design.295985b3.js.map
