import{U as s}from"./outputWidgets.32262ea4.js";import{c as i,d as f}from"./index.9fd37fcf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="89f1340f-5486-4ead-a9a0-8cf68e6c411f",e._sentryDebugIdIdentifier="sentry-dbid-89f1340f-5486-4ead-a9a0-8cf68e6c411f")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:d,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(f),g=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:d,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{g as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.53e4e618.js.map
