import{U as t,f as d,O as c,ab as y}from"./outputWidgets.32262ea4.js";import{B as i,b as l}from"./Title.4f1fbb5b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="c1029f75-cdc4-4ed3-b276-ae0336c1e1bf",e._sentryDebugIdIdentifier="sentry-dbid-c1029f75-cdc4-4ed3-b276-ae0336c1e1bf")}catch{}})();const b=()=>c(l(),["component"]),r=(e,s)=>{let{slots:o,attrs:p}=s;const a=t(t(t({},e),{component:"div"}),p);return d(i,a,o)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=b();const m=r,g=()=>t(t({},c(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),n=(e,s)=>{let{slots:o,attrs:p}=s;const{ellipsis:a}=e;y();const f=t(t(t({},e),{ellipsis:a&&typeof a=="object"?c(a,["expandable","rows"]):a,component:"span"}),p);return d(i,f,o)};n.displayName="ATypographyText";n.inheritAttrs=!1;n.props=g();const x=n;export{m as A,x as a};
//# sourceMappingURL=Text.5738d3bb.js.map
