import{v as t,b as s,ev as d}from"./outputWidgets.32262ea4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="79d6db3b-b210-4733-b18d-a00546c63b68",e._sentryDebugIdIdentifier="sentry-dbid-79d6db3b-b210-4733-b18d-a00546c63b68")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),d("div",r,"Organization settings")}const b=t(o,[["render",i]]);export{b as default};
//# sourceMappingURL=OrganizationSettings.ac07b292.js.map
