import{d as k,eB as B,eA as I,G as w,a as h,b as o,c as d,w as a,eJ as j,f as n,u as t,ev as c,eC as x,aq as g,eD as z,bq as C,ex as D,bg as A,cC as S}from"./outputWidgets.32262ea4.js";import{B as $}from"./BaseLayout.6bbf44f6.js";import{a as M}from"./asyncComputed.2515c9c2.js";import{_ as N}from"./component.vue_vue_type_script_setup_true_lang.66532bde.js";import"./authorManager.bf87d9ac.js";import{a as P}from"./build.287e91be.js";import"./index.2dfe4d35.js";import{P as R}from"./project.9d2c85ac.js";import{O as V}from"./organization.f1af1618.js";import{B as q,a as E,c as L}from"./index.3d4aee4e.js";import{a as O}from"./Text.5738d3bb.js";import"./gateway.c70bbf22.js";import"./WarningFilled.d99917ef.js";import"./log.ae297d1d.js";import"./ant-design.295985b3.js";import"./index.c9aa3d70.js";import"./Modal.1c897574.js";import"./index.9148038a.js";import"./Link.adad6177.js";import"./Title.4f1fbb5b.js";import"./index.1d7a7a89.js";import"./TabPane.8fd38a7c.js";import"./hasIn.4e5c4024.js";import"./index.8a26b344.js";import"./isNumeric.75337b1e.js";import"./icons.f6f8ddd9.js";import"./index.3d75876c.js";import"./FormItem.dc863e60.js";import"./index.cf4c23b9.js";import"./record.b25fae92.js";import"./pubsub.688bf9b2.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[s]="7c9cc8bf-a969-4783-a761-9d7d39632e43",i._sentryDebugIdIdentifier="sentry-dbid-7c9cc8bf-a969-4783-a761-9d7d39632e43")}catch{}})();const T={key:0},F={key:2},Bt=k({__name:"Build",setup(i){const s=B(),l=I(),m=s.params.buildId,{result:e,loading:f}=M(async()=>{const r=await P.get(m),p=await R.get(r.projectId),u=await V.get(p.organizationId);return j({bs:r,project:p,organization:u})}),b=w(()=>!f.value&&e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.organization.name,path:`/organizations/${e.value.organization.id}`},{label:`Build ${m.split("-")[0]}`,path:`/projects/${e.value.project.id}/builds`}]:void 0);function y(){var r;(r=e.value)!=null&&r.project.id&&l.push({name:"builds",params:{projectId:e.value.project.id}})}return(r,p)=>{const u=h("router-link");return o(),d($,null,{navbar:a(()=>[n(t(L),{title:"Inspect Build",style:{padding:"5px 25px"},onBack:y},{breadcrumb:a(()=>[b.value?(o(),d(t(q),{key:0},{default:a(()=>[(o(!0),c(C,null,x(b.value,(_,v)=>(o(),d(t(E),{key:v},{default:a(()=>[n(u,{to:_.path},{default:a(()=>[g(z(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):D("",!0)]),_:1})]),content:a(()=>[t(f)?(o(),c("div",T,[n(t(A))])):t(e)?(o(),d(N,{key:1,"build-spec":t(e).bs},null,8,["build-spec"])):(o(),c("div",F,[n(t(S),{direction:"vertical"},{default:a(()=>[n(t(O),null,{default:a(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{Bt as default};
//# sourceMappingURL=Build.0254bd1f.js.map
